==> models_weebi-1.1.2.tar.gz: lib/src/models/common/address.dart <==
// Dart imports:
import 'dart:convert';

import 'package:models_weebi/common.dart';
import 'package:models_weebi/src/extensions/string_no_accents.dart';
import 'package:models_weebi/src/models/common/country.dart';

class Address {
  final String street;
  final String code;
  final String city;
  final Country country;
  final double latitude;
  final double longitude;

  const Address(
      {required this.street,
      required this.city,
      this.code = '',
      required this.country,
      this.latitude = 0.0,
      this.longitude = 0.0});

  const Address._empty(this.street, this.code, this.city, this.country,
      {this.latitude = 0.0, this.longitude = 0.0});

  static const empty =
      Address._empty('', '', '', Country.empty, latitude: 0.0, longitude: 0.0);

  Address copyWith({
    String? street,
    String? code,
    String? city,
    Country? country,
    double? latitude,
    double? longitude,
  }) {
    return Address(
      street: street ?? this.street,
      city: city ?? this.city,
      country: country ?? this.country,
      code: code ?? this.code,
      latitude: latitude ?? this.latitude,
      longitude: longitude ?? this.longitude,
    );
  }

  Map<String, Object> toMap() {
    return {
      'street': street,
      'city': city,
      'country': country.toMap(),
      'code': code,
      'latitude': latitude,
      'longitude': longitude,
    };
  }

  factory Address.fromMap(Map<String, dynamic> map) {
    return Address(
      street: map['street'] ?? '',
      city: map['city'] ?? '',
      code: map['code'] ?? '',
      country: map['country'] != null
          ? Country.fromMap(map['country'])
          : Country.empty,
      latitude: map['latitude'] ?? 0.0,
      longitude: map['longitude'] ?? 0.0,
    );
  }

  String toJson() => json.encode(toMap());

  factory Address.fromJson(String source) =>
      Address.fromMap(json.decode(source));

  @override
  String toString() {
    return '${street.withoutAccents}\n$code ${city.withoutAccents}';
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is Address &&
        other.street == street &&
        other.code == code &&
        other.city == city &&
        other.country == country;
  }

  @override
  int get hashCode {
    return street.hashCode ^ code.hashCode ^ city.hashCode ^ country.hashCode;
  }
}

==> models_weebi-1.1.4.tar.gz: lib/src/models/common/address.dart <==
// Dart imports:
import 'dart:convert';

import 'package:models_weebi/common.dart';
import 'package:models_weebi/src/extensions/string_no_accents.dart';
import 'package:models_weebi/src/models/common/country.dart';

class Address {
  final String street;
  final String code;
  final String city;
  final Country country;
  final double latitude;
  final double longitude;

  const Address(
      {required this.street,
      required this.city,
      this.code = '',
      required this.country,
      this.latitude = 0.0,
      this.longitude = 0.0});

  const Address._empty(this.street, this.code, this.city, this.country,
      {this.latitude = 0.0, this.longitude = 0.0});

  static const empty =
      Address._empty('', '', '', Country.empty, latitude: 0.0, longitude: 0.0);

  Address copyWith({
    String? street,
    String? code,
    String? city,
    Country? country,
    double? latitude,
    double? longitude,
  }) {
    return Address(
      street: street ?? this.street,
      city: city ?? this.city,
      country: country ?? this.country,
      code: code ?? this.code,
      latitude: latitude ?? this.latitude,
      longitude: longitude ?? this.longitude,
    );
  }

  Map<String, Object> toMap() {
    return {
      'street': street,
      'city': city,
      'country': country.toMap(),
      'code': code,
      'latitude': latitude,
      'longitude': longitude,
    };
  }

  factory Address.fromMap(Map<String, dynamic> map) {
    return Address(
      street: map['street'] ?? '',
      city: map['city'] ?? '',
      code: map['code'] ?? '',
      country: map['country'] != null
          ? Country.fromMap(map['country'])
          : Country.empty,
      latitude: map['latitude'] ?? 0.0,
      longitude: map['longitude'] ?? 0.0,
    );
  }

  String toJson() => json.encode(toMap());

  factory Address.fromJson(String source) =>
      Address.fromMap(json.decode(source));

  @override
  String toString() {
    return code.isEmpty
        ? '${street.withoutAccents}\n${city.withoutAccents}'
        : '${street.withoutAccents}\n$code ${city.withoutAccents}';
  }

  String toStringWithCountry() {
    return code.isEmpty
        ? '${street.withoutAccents}\n${city.withoutAccents}\n${country.toString()}'
        : '${street.withoutAccents}\n$code ${city.withoutAccents}\n${country.toString()}';
  }

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is Address &&
        other.street == street &&
        other.code == code &&
        other.city == city &&
        other.country == country;
  }

  @override
  int get hashCode {
    return street.hashCode ^ code.hashCode ^ city.hashCode ^ country.hashCode;
  }
}
